@@ -799,6 +799,8 @@ class LogicaProgram(object):
         defines_and_exports +
         FormatSql(sql))
     if True:
+      self.execution.preamble = self.UseFlagsAsParameters(
+          self.execution.preamble)
       for k, v in self.execution.table_to_export_map.items():
         self.execution.table_to_export_map[k] = self.UseFlagsAsParameters(v)
       for i, d in enumerate(self.execution.defines):
@@ -904,10 +906,13 @@ class LogicaProgram(object):
       s.tables = new_tables
 
   def SingleRuleSql(self, rule,
-                    allocator=None, external_vocabulary=None):
+                    allocator=None, external_vocabulary=None,
+                    is_combine=False):
     """Producing SQL for a given rule in the program."""
     allocator = allocator or self.NewNamesAllocator()
     r = rule
+    if (is_combine):
+      r = self.execution.dialect.DecorateCombineRule(r, allocator.AllocateVar())
     s = rule_translate.ExtractRuleStructure(
         r, allocator, external_vocabulary)
 
@@ -1056,8 +1061,10 @@ class SubqueryTranslator(object):
       self.execution.workflow_predicates_stack[-1]))
     return self.UnquoteParenthesised(table)
 
-  def TranslateRule(self, rule, external_vocabulary):
-    return self.program.SingleRuleSql(rule, self.allocator, external_vocabulary)
+  def TranslateRule(self, rule, external_vocabulary, is_combine=False):
+    return self.program.SingleRuleSql(
+      rule, self.allocator, external_vocabulary,
+      is_combine=is_combine)
 
 
 def InjectStructure(target, source):
